# JournalRunStatus

Status of the journal run

## Enum

* `PENDING` (value: `'Pending'`)

* `PROCESSING` (value: `'Processing'`)

* `COMPLETED` (value: `'Completed'`)

* `ERROR` (value: `'Error'`)

* `CANCELINPROGRESS` (value: `'CancelInprogress'`)

* `CANCELLED` (value: `'Cancelled'`)

* `DELETEINPROGRESS` (value: `'DeleteInprogress'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


